@@ -17,7 +17,7 @@ use Text::Abbrev();
 use Exporter ();
 our @ISA = qw{ Exporter };
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 our @EXPORT_OK = qw{
     __am_or_pm
@@ -639,7 +639,7 @@ sub _fmt_on_date {
     $on_date[3][28]  = "Celeborn crosses the Anduin and begins destruction of Dol Guldur, 1419.\n";
 
     $on_date[4][6]   = "The mallorn tree flowers in the party field, 1420.\n";
-    $on_date[4][8]   = "Ring bearers are honored on the fields of Cormallen, 1419.\n";
+    $on_date[4][8]   = "Ring bearers are honored on the Field of Cormallen, 1419.\n";
     $on_date[4][12]  = "Gandalf arrives in Hobbiton, 1418\n";
 
     $on_date[5][1]   = "Crowning of King Elessar, 1419.\n" .
